<?php
$TRANSLATIONS = array(
"Couldn't delete %s permanently" => "Impossible de supprimer %s définitivement",
"Couldn't restore %s" => "Impossible de restaurer %s",
"Deleted files" => "Fichiers supprimés",
"Restore" => "Restaurer",
"Error" => "Erreur",
"restored" => "restauré",
"Nothing in here. Your trash bin is empty!" => "Il n'y a rien ici. Votre corbeille est vide !",
"Name" => "Nom",
"Deleted" => "Effacé",
"Delete" => "Supprimer"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
